@@ -20,72 +20,281 @@
 #' files can become extremely large (use print_inds with extreme caution and
 #' print_last with care).
 #' 
-#'@param mine_output The output from mine_gmatrix
-#'@param N Number of individuals to be initialised
-#'@param xdim Horizontal dimensions of the landscape
-#'@param ydim Vertical dimensions of the landscape
-#'@param repro Type of reproduction allowed: "asexual", "sexual", and
-#'  "biparental". Note that if repro > 0, this causes a diploid genome.
-#'@param neutral_loci The number of neutral loci individuals have
-#'@param max_age The maximum age of an individual
-#'@param min_age_move The minimum age at which an individual can move
-#'@param max_age_move The maximum age at which an individual can move
-#'@param min_age_reproduce The minimum age which an individual can reproduce
-#'@param max_age_reproduce The maximum age which an individual can reproduce
-#'@param min_age_feed The minimum age at which an individual feeds
-#'@param max_age_feed The maximum age at which an individual feeds
-#'@param food_consume The amount of food consumed during feeding
-#'@param pesticide_consume Amount of pesticide consumed while on a cell
-#'@param rand_age Initialise individuals with a random age
-#'@param move_distance Maximum cells moved in one bout of movement
-#'@param food_needed_surv Food needed to survive (if over min_age_feed)
-#'@param pesticide_tolerated_surv Pesticide tolerated by individual
-#'@param food_needed_repr Food needed to reproduce 1 offspring
-#'@param pesticide_tolerated_repr Pesticide tolerated to allow reproduction
-#'@param reproduction_type Poisson reproduction ("lambda") vs "food_based"
-#'@param mating_distance Distance in cells within which mate is available
-#'@param lambda_value individual value for poisson reproduction
-#'@param movement_bouts Number of bouts of movement per time step
-#'@param selfing If sexual reproduction, is selfing allowed?
-#'@param feed_while_moving Do individuals feed after each movement bout?
-#'@param pesticide_while_moving Individuals consume pesticide after move bout?
-#'@param mortality_type Type of mortality (currently only one option)
-#'@param age_food_threshold Age at which food threshold is enacted
-#'@param age_pesticide_threshold Age at which pesticide threshold is enacted
-#'@param farms How many farms should there be on the landscape?
-#'@param time_steps Time steps in the simulation
-#'@param mutation_pr Probability of a loci mutating
-#'@param crossover_pr Probability of crossover at homologous loci
-#'@param mutation_type Type of mutation used
-#'@param net_mu_layers Layers of the network allowed to mutate
-#'@param net_mu_dir  Layers mutate from loci to (1) or traits back (0)
-#'@param mutation_direction Is mutation directional (unlikely to need)
-#'@param crop_rotation_type None (1) or random (2) rotation of crop type
-#'@param crop_rotation_time How frequently are the crops rotated?
-#'@param pesticide_rotation_type None (1) or random (2) rotation of pesticide
-#'@param pesticide_rotation_time How frequently are the pesticides rotated?
-#'@param crop_per_cell How much crop is put on a single cell?
-#'@param pesticide_per_cell How much pesticide is put on a single cell?
-#'@param crop_sd What is the standard deviation of crop on a cell?
-#'@param pesticide_sd What is the standard deviation of pesticide on a cell?
-#'@param crop_min What is the minimum crop amount allowed per cell?
-#'@param crop_max What is the maximum crop amount allowed per cell?
-#'@param pesticide_min What is the minimum pesticide amount allowed per cell?
-#'@param pesticide_max What is the maximum pesticide amount allowed per cell?
-#'@param crop_number How many crops exist on the landscape?
-#'@param pesticide_number How many pesticides are applied on the landscape?
-#'@param print_inds Should the full list of individuals be printed? (CAREFUL)
-#'@param print_gens Should a summary of each time step be printed?
-#'@param print_last Should the last time step of individuals be printed?
-#'@param K_on_birth Is there a carrying capacity applied on newborns?
-#'@param pesticide_start What time step should pesticide start being applied?
-#'@param immigration_rate Mean number of immigrants per time step
-#'@param get_f_coef Get the inbreeding coefficient (not for asexual)
-#'@param get_stats Get population level statistics in a CSV printout
-#'@param metabolism The rate at which food consumed is burned in a time step
-#'@param baseline_metabolism A fixed baseline rate added to 'metabolism'
-#'@param min_age_metabolism The minimum age affected by metabolism
-#'@param max_age_metabolism The maximum age affected by metabolism
+#'@param mine_output The output from mine_gmatrix, which will be used to
+#' initialise the genomes and traits of pests.
+#'@param N The number of individuals that are initialised in a simulation. 
+#' Individuals are initialised in a random location on the landscape, and at 
+#' least two individuals are needed.
+#'@param xdim The number of cells in the horizontal dimension of the landscape. 
+#' This value must be an integer greater than two.
+#'@param ydim The number of cells in the vertical dimension of the landscape. 
+#' This value must be an integer greater than two.
+#'@param repro The type of reproduction that individuals undergo in the 
+#' simulation. There are three options: (1) "asexual," in which individuals 
+#' reproduce clonally and offspring have haploid genomes and traits identical to
+#' their mother with the potential for mutation; (2) "sexual," in which 
+#' individuals are monoecious (both female and male) and offspring have diploid 
+#' genomes with alleles inherited from both parents with mutation and 
+#' recombination; (3) "biparental," in which individuals are dioecious (only 
+#' female or male) and offspring have diploid genomes with alleles inherited 
+#' from both parents with mutation and recombination.
+#'@param neutral_loci The number of loci that are completely neutral (i.e., have
+#' no effect on fitness). These loci can be used to monitor genetic drift or
+#' calculate inbreeding coefficients.
+#'@param max_age This is the maximum number of time steps that an individual can
+#' survive. Individuals that are older than this age in a time step will always 
+#' die.
+#'@param min_age_move This is the minimum age at which an individual can move. 
+#' Individuals below this age will always remain on their current cell.
+#'@param max_age_move This is the maximum age at which an individual can move. 
+#' Individuals above this age will always remain on their current cell.
+#'@param min_age_reproduce This is the minimum age at which an individual can be
+#' reproductively active. No individuals below this age will engage in any 
+#' reproductive activity, nor will they be recognised as potential mates by 
+#' other individuals.
+#'@param max_age_reproduce This is the maximum age at which an individual can be
+#' reproductively active. No individuals above this age will engage in any
+#' reproductive activity, nor will they be recognised as potential mates by
+#' other individuals.
+#'@param min_age_feed This is the minimum age at which an individual can eat. No
+#' individuals below this age will be able to consume food on the landscape.
+#'@param max_age_feed This is the maximum age at which an individual can eat. No
+#' individuals above this age will be able to consume food on the landscape.
+#'@param food_consume This defines how much food an individual will consume from
+#' the cell on which it is feeding. Food consumption can take on any positive
+#' real value, and an individual will consume up to this amount if possible (if 
+#' not, they will consume however much food is left within their landscape 
+#' cell).
+#'@param pesticide_consume This defines how much pesticide an individual will
+#' consume from the cell on which it resides. Pesticide consumption can take on 
+#' any positive real value, and an individual will consume up to this amount if
+#' possible (if not, they will consume however much pesticide has been placed on
+#' the landscape cell).
+#'@param rand_age This argument determines whether individuals in the simulation
+#' will be initialised with a random age selected uniformly from zero to 
+#' max_age. If FALSE, then all individuals will be initialised at age zero.
+#'@param move_distance This is the maximum number of cells that an individual 
+#' can move, in any direction, on the landscape during one bout of movement.
+#'@param food_needed_surv This is the amount of food that an individual needs to
+#' consume to survive. If the individual has not consumed this amount of food 
+#' before the age of age_food_threshold, then they will die in the time step.
+#'@param pesticide_tolerated_surv This is the amount of pesticide that an 
+#' individual can tolerate and still survive. If the individual has consumed 
+#' more than this amount of pesticide on or after the age of 
+#' age_pesticide_threshold, then they will die in the time step.
+#'@param food_needed_repr This is the amount of food that an individual needs to
+#' produce one offspring. The total number of offspring that an individual 
+#' produces in a time step is the floor value of their food consumption divided 
+#' by this value.
+#'@param pesticide_tolerated_repr This is the amount of pesticide tolerated 
+#' below which an individual can reproduce. Note that individuals above the 
+#' threshold can still mate and sire offspring,
+#'@param reproduction_type This determines how individuals reproduce; the two 
+#' options are "lambda" and "food_based." If "lambda," then the number of 
+#' offspring an individual produces is sampled from a Poisson distribution with 
+#' a fixed rate parameter lambda_value (potentially adjusted by other factors in
+#' the simulation). If "food_based," then the number of offspring produced is 
+#' based on the amount of food consumed by the individual.
+#'@param mating_distance This is the distance in cells (any direction) away from
+#' a focal individual from which they can successfully find and identify a mate 
+#' (e.g., if 0, then only individuals on the same cell are potential mates).
+#'@param lambda_value This is the rate parameter for the Poisson sampling of 
+#' offspring number; it only applies when reproduction_type is set to "lambda."
+#'@param movement_bouts This is the number of times an individual can move in a 
+#' single time step (i.e., the number of cells that it can potentially visit). 
+#' Each time an individual visits a new cell, it can potentially feed or consume 
+#' pesticide.
+#'@param selfing This determines whether or not self-fertilisation is allowed 
+#' when repro is set to "sexual."
+#'@param feed_while_moving If TRUE, then individuals will feed in each movement 
+#' bout when they arrive to a new landscape cell.
+#'@param pesticide_while_moving If TRUE, then individuals will consume pesticide
+#' in each movement bout when they arrive to a new landscape cell.
+#'@param mortality_type This determines how mortality is enacted in the 
+#' simulation. Currently there is only one mortality type possible; mortality 
+#' occurs if individuals exceed their maximum age, do not consume enough food, 
+#' or consume too much pesticide.
+#'@param age_food_threshold This is the age at which mortality associated with 
+#' feeding is enacted, so an individual younger than this age will not die if 
+#' they have not yet consumed sufficient food to satisfy food_needed_surv.
+#'@param age_pesticide_threshold This is the age at which mortality associated 
+#' with pesticide consumption is enacted, so an individual younger than this age
+#' will not die even if they have exceeded their pesticide threshold.
+#'@param farms This is the number of farms to be placed on the landscape. Farms 
+#' are placed in blocks of roughly equal sizes using a shortest splitline 
+#' algorithm. Farms operate independently in terms of what crops they grow and 
+#' pesticides they apply.
+#'@param time_steps This is the number of time steps that a simulation will run.
+#' Simulations will be terminated before this number if extinction occurs.
+#'@param mutation_pr This is the probability of mutation occurring at any locus 
+#' of a newly produced offspring.
+#'@param crossover_pr This is the probability of crossover between two 
+#' homologous loci. This only applies for diploid genomes.
+#'@param mutation_type This determines how mutation is modelled. If 0, then a 
+#' completely new allele value is drawn from a normal distribution with a mean 
+#' of mutation_direction and a standard deviation of 1 (or 1 / sqrt(2) for 
+#' diploids, so that the expected standard devation of the sum of both allele 
+#' values is 1). If 1, then a new value is drawn from a normal distribution with
+#' mean mutation_direction and standard deviation of 1, and this new value is 
+#' then added to the existing allele value.
+#'@param net_mu_layers This is the proportion of the genome that can evolve. If 
+#' 0, then only loci values (green circles in Figure 1) can mutate. If 1, then 
+#' loci and the first column of arrows (green circles to first column of blue 
+#' squares in Figure 1) can mutate. If 2, then the first two columns of arrows 
+#' in Figure 1 can mutate, and so forth. Fewer mutation layers will constrain 
+#' the covariance among traits, while more mutation layers will allow the 
+#' covariance structure to evolve more readily.
+#'@param net_mu_dir  The direction along the network in which net_mu_layers 
+#' applies (not loci, green circles in Figure 1, can always mutate). If 1, then 
+#' net_mu_layers applies in the direction from loci to traits. If 0, then the 
+#' direction applies from traits to loci (i.e., net_mu_dir = 0 and 
+#' net_mu_layers = 1 would mean that only the arrow values between the last 
+#' hidden layer and traits in Figure 1 could mutate).
+#'@param mutation_direction This allows mutations to be biased in one direction.
+#' A default value of 0 makes positive or negative allele values equally likely.
+#'@param crop_init Initial crop type for each farm. This can be set in one of 
+#' two ways. First, the default value "random" will randomly assign each farm to
+#' an initial crop to produce. Second, a vector can be used to specify the crop
+#' initialised on each farm. The vector must be the same length as the number of
+#' farms, and the value of each element 'i' of the vector defines which crop is
+#' initialised for each farm i. Hence, a crop_init vector must have as many
+#' elements as there are farms, and vector elements must include natural numbers
+#' from 1 to the total number of crops.
+#'@param crop_rotation_type This determines how crop types are rotated across 
+#' the landscape. This can be set in one of two ways. First, a natural number
+#' can specify a rotation type: (1) crops will never rotate, (2) a new crop type
+#' will be randomly chosen every crop_rotation_time time steps for each farm, 
+#' or (3) farms will cycle through crop types in order, with a change from one
+#' crop type to another every crop_rotation_time time step. Second, a square 
+#' matrix can specify the probability of transition from a focal crop type 
+#' (rows) to the next crop type (columns). Matrix rows must therefore sum to 1. 
+#' For example, an identity matrix (1s in the diagonal and 0s in the 
+#' off-diagonal) would specify crops that never rotate (i.e., crop i always 
+#' rotates to itself).
+#'@param crop_rotation_time This determines how many time steps a crop is left 
+#' before being refreshed and potentially changed. Note that even if the crop 
+#' type does not change, this value still has the effect of determining how 
+#' often crops are replenished (if some have been eaten since the last time they
+#' were replenished).
+#'@param pesticide_init Initial pesticide type for each farm. This can be set in
+#' one of two ways. First, the default value "random" will randomly assign each 
+#' farm to an initial pesticide to apply. Second, a vector can be used to 
+#' specify the pesticide initialised on each farm. The vector must be the same 
+#' length as the number of farms, and the value of each element 'i' of the 
+#' vector defines which pesticide is initialised for each farm i. Hence, a 
+#' pesticide_init vector must have as many elements as there are farms, and 
+#' vector elements must include natural numbers from 1 to the total number of 
+#' pesticides.
+#'@param pesticide_rotation_type This determines how pesticide types are rotated
+#' across the landscape. This can be set in one of two ways. First, a natural 
+#' number can specify a rotation type: (1) pesticides will never rotate, (2) a 
+#' new pesticide type will be randomly chosen every pesticide_rotation_time time
+#' steps for each farm, or (3) farms will cycle through pesticide types in 
+#' order, with a change from one pesticide type to another every 
+#' pesticide_rotation_time time step. Second, a square matrix can specify the 
+#' probability of transition from a focal pesticide type (rows) to the next 
+#' pesticide type (columns). Matrix rows must therefore sum to 1. For example, 
+#' an identity matrix (1s in the diagonal and 0s in the off-diagonal) would 
+#' specify pesticides that never rotate (i.e., pesticide i always rotates to 
+#' itself).
+#'@param pesticide_rotation_time This determines how many time steps a pesticide
+#' is left before being replenished and potentially changed. Note that unlike 
+#' crops, pesticide levels do not decrease on the landscape over time (e.g., 
+#' with consumption).
+#'@param crop_per_cell This determines the expected amount of crop that is 
+#' placed on a single landscape cell. The more crop on a cell, the more that can
+#' be potentially consumed by individuals.
+#'@param pesticide_per_cell This determines how much pesticide is placed on a 
+#' single landscape cell. The higher concentration of pesticide per cell, the 
+#' more that individuals on the cell will imbibe and potentially be affected by.
+#'@param crop_sd This is the standard deviation of crop number placed on 
+#' landscape cells. A default value of 0 assumes that all cells have the same 
+#' amount of crop.
+#'@param pesticide_sd This is the standard deviation of pesticide applied to 
+#' each landscape cell. A default value of 0 assumes that each cell has the same
+#' concentration of pesticide applied.
+#'@param crop_min This is the minimum amount of crop that is possible to have on
+#' a single cell (i.e., crop values will never be initialised to be lower than 
+#' this value).
+#'@param crop_max This is the maximum amount of crop that is possible to have on
+#' a single cell (i.e., crop values will never be initialised to be higher than 
+#' this value).
+#'@param pesticide_min This is the minimum concentration of pesticide that is 
+#' possible to have on a single cell (i.e., pesticide values will never be 
+#' initialised to be lower than this value).
+#'@param pesticide_max This is the maximum concentration of pesticide that is 
+#' possible to have on a single cell (i.e., pesticide values will never be 
+#' initialised to be higher than this value).
+#'@param crop_number This is the number of unique crops that can exist on the 
+#' landscape during the course of a simulation. The maximum number of possible 
+#' crops is 10.
+#'@param pesticide_number This is the number of unique pesticides that can exist
+#' on the landscape during the course of a simulation. The maximum number of 
+#' possible pesticides is 10.
+#'@param print_inds If TRUE, a CSV file will print in the working directory with
+#' every individual and all of their characteristics (i.e., locations, traits, 
+#' genomes) in every time step. By default, this is set to FALSE and should only
+#' be set to TRUE with extreme caution, as large populations persisting over 
+#' long periods of time can produce extremely large CSV files.
+#'@param print_gens If TRUE, the time step and the population size will be 
+#' printed to the R console as the simulation is running.
+#'@param print_last If TRUE, a CSV file will print in the working directory with
+#' every individual and all of their characteristics (i.e., locations, traits, 
+#' genomes) in only the last time step. Note that for large populations, the 
+#' file size generated can be very large (10s to 100s of GBs).
+#'@param K_on_birth This is a carrying capacity applied to new individuals 
+#' across the entire landscape. If the total number of offspring in a time step 
+#' exceeds this value, then offspring are removed at random until the total 
+#' number of new offspring equals K_on_birth. In practice, this can help speed 
+#' up simulations by avoiding the unnecessary production of individuals when 
+#' most will perish.
+#'@param pesticide_start This is the time step at which pesticide begins to be 
+#' applied. No pesticide will be applied prior to this start time, so 
+#' individuals will not experience any effects of pesticide. This can be useful 
+#' as a tool to burn in the population prior to introducing pesticide.
+#'@param immigration_rate This is the number of immigrant individuals arriving 
+#' in the landscape in each time step. Immigrants are initialised in random 
+#' locations with the same network structure (Figure 1) as individuals 
+#' initialised at the start of the simulation, and with allele values randomly 
+#' drawn from a standard normal distribution.
+#'@param get_f_coef This determines whether or not inbreeding coefficients will 
+#' be calculated for sexual populations and printed off in CSV files. Because 
+#' this can add some computation time, it is best to set to FALSE unless it is 
+#' needed.
+#'@param get_stats If TRUE, a CSV file will print in the working directory with 
+#' summary statistics for each time step. This is set to TRUE by default.
+#'@param metabolism This determines the rate at which food consumed in previous 
+#' time steps is lost in subsequent time steps, which can be especially relevant
+#' if food consumed determines survival or reproductive output. Values of 0 mean
+#' that stored gains will always persist throughout an individual’s lifetime, 
+#' while very high values will model the gains of one time step being wiped out 
+#' in subsequent time steps (if, e.g., the objective is to model individuals 
+#' needing to consume food successfully in each time step to survive or 
+#' reproduce, as opposed to having a feeding life history stage followed by a 
+#' mating and reproduction stage).
+#'@param baseline_metabolism This fixes a baseline metabolic rate at which food 
+#' consumed in previous time steps is lost in subsequent steps. This fixed value
+#' is always added to metabolism for each individual. By default, this value is 
+#' 0.
+#'@param min_age_metabolism This determines the minimum age at which losses of 
+#' food consumed in previous time steps enacted by metabolism and 
+#' baseline_metabolsim can occur.
+#'@param max_age_metabolism This determines the maximum age at which losses of 
+#' food consumed in previous time steps enacted by metabolism and 
+#' baseline_metabolsim can occur.
+#'@param terrain Insert a custom terrain of different farms, which takes the
+#' form of a matrix that includes a sequence of natural numbers in all matrix
+#' elements. For example, if there are 4 farms, then all matrix elements must
+#' be 1, 2, 3, or 4. Beyond this requirement, there is no restriction on where 
+#' different farms are placed; the do not even need to be contiguous on the 
+#' landscape. Note that a custom terrain will override the arguments farms, 
+#' xdim, and ydim. For example, if the matrix given to the terrain argument has
+#' 10 rows and 10 columns, then the simulation will automatically set xdim and
+#' ydim equal to 10 without any warnings. Also note that these terrain values do
+#' not necessarily need to be farms. Through the use of a custom landscape and 
+#' pesticide rotation option, these cells could represent something like 
+#' diversionary feeding sites or even buildings or rivers. See vignettes and 
+#' other documentation for details.
 #'@return The output in the R console is a list with two elements; the first 
 #'element is a vector of parameter values used by the model, and the second 
 #'element is the landscape in the simulation. The most relevant output will be
@@ -149,8 +358,10 @@ run_farm_sim <- function(mine_output,
                          net_mu_layers = 0,
                          net_mu_dir = 0, 
                          mutation_direction = 0,
+                         crop_init = "random",
                          crop_rotation_type = 2,
                          crop_rotation_time = 1,
+                         pesticide_init = "random",
                          pesticide_rotation_type = 2,
                          pesticide_rotation_time = 1,
                          crop_per_cell = 1,
@@ -174,10 +385,18 @@ run_farm_sim <- function(mine_output,
                          metabolism = 0,
                          baseline_metabolism = 0,
                          min_age_metabolism  = 1,
-                         max_age_metabolism  = 9){
-  
-    land <- make_landscape(rows = ydim, cols = xdim, depth = 21, farms = farms);
+                         max_age_metabolism  = 9,
+                         terrain             = NA){
   
+    if(is.na(terrain)[1] == FALSE){
+        xdim  <- dim(terrain)[1];
+        ydim  <- dim(terrain)[2];
+        farms <- max(terrain);
+    }
+    
+    land <- make_landscape(terrain = terrain, rows = ydim, cols = xdim, 
+                           depth = 21, farms = farms);
+
     move_distance_T             <- check_is_trait(move_distance);
     food_needed_surv_T          <- check_is_trait(food_needed_surv);
     pesticide_tolerated_surv_T  <- check_is_trait(pesticide_tolerated_surv);
@@ -247,6 +466,12 @@ run_farm_sim <- function(mine_output,
     if(N < 5){
       stop("Need to start with at least 5 pests");
     }
+    if(crop_number > 10){
+        stop("Cannot have more than 10 crops");
+    }
+    if(pesticide_number > 10){
+        stop("Cannot have more than 10 pesticides");
+    }
     
     food_consume <- as.list(food_consume);
     food_cons    <- NULL;
@@ -315,8 +540,10 @@ run_farm_sim <- function(mine_output,
                              net_mu_layers            = net_mu_layers, 
                              net_mu_dir               = net_mu_dir,
                              mutation_direction       = mutation_direction,
+                             crop_init                = crop_init,
                              crop_rotation_type       = crop_rotation_type,
                              crop_rotation_time       = crop_rotation_time,
+                             pesticide_init           = pesticide_init,
                              pesticide_rotation_type  = pesticide_rotation_type,
                              pesticide_rotation_time  = pesticide_rotation_time,
                              crop_per_cell            = crop_per_cell,
@@ -347,7 +574,8 @@ run_farm_sim <- function(mine_output,
                              immigration_rate         = immigration_rate,
                              get_f_coef               = get_f_coef,
                              get_stats                = get_stats,
-                             metabolism               = metabolism);
+                             metabolism               = metabolism,
+                             farms                    = farms);
   
     return(sim_results);
 }
@@ -361,8 +589,10 @@ sim_crops <- function(pests,
                       net_mu_layers = 0,
                       net_mu_dir = 0, 
                       mutation_direction = 0,
+                      crop_init = "random",
                       crop_rotation_type = 2,
                       crop_rotation_time = 1,
+                      pesticide_init = "random",
                       pesticide_rotation_type = 2,
                       pesticide_rotation_time = 1,
                       crop_per_cell = 1,
@@ -393,7 +623,8 @@ sim_crops <- function(pests,
                       immigration_rate = 0,
                       get_f_coef = FALSE,
                       get_stats  = TRUE,
-                      metabolism = 0
+                      metabolism = 0,
+                      farms = 4
                       ){
   
   N    <- dim(pests)[1];
@@ -410,9 +641,7 @@ sim_crops <- function(pests,
   netm <- net_mu_layers;
   mudr <- mutation_direction;
   netd <- net_mu_dir;
-  crty <- crop_rotation_type;
   crti <- crop_rotation_time;
-  prty <- pesticide_rotation_type;
   prti <- pesticide_rotation_time;
   crpc <- crop_per_cell;
   pepc <- pesticide_per_cell;
@@ -575,14 +804,14 @@ sim_crops <- function(pests,
               N,      # 139) Number of individuals in the next time step
               ts,     # 140) Total number of time steps to run
               0,      # 141) Extinction has occurred
-              crty,   # 142) Type of crop rotation
+              farms,  # 142) Total number of farms
               crti,   # 143) Time steps between crop rotation
               crpc,   # 144) Crop production per landscape cell
               0,      # 145) Type of crop production (UNUSED)
               crmn,   # 146) Minimum crop production per landscape cell
               crmx,   # 147) Maximum crop production per landscape cell
-              prty,   # 148) Type of biopesticide rotation
-              crti,   # 149) Time steps between biopesticide rotation
+              1,      # 148) Type of biopesticide rotation (no longer used)
+              prti,   # 149) Time steps between biopesticide rotation
               pepc,   # 150) Biopesticide amount per landscape cell
               0,      # 151) Type of biopesticide application (UNUSED)
               pssd,   # 152) StDev in biopesticide per landscape cell
@@ -621,13 +850,19 @@ sim_crops <- function(pests,
     stop("ERROR: land must be a 3D array.");
   }
   
-  SIM_RESULTS        <- run_farming_sim(pests, land, paras);
+  c_rotate     <- crop_transitions(crop_rotation_type, crpN);
+  p_rotate     <- pesticide_transitions(pesticide_rotation_type, pesN); 
+  c_init       <- initialise_crops(crop_init, crpN, farms);
+  p_init       <- initialise_pesticide(pesticide_init, pesN, farms); 
+
+  SIM_RESULTS  <- run_farming_sim(pests, land, paras, c_rotate, p_rotate,
+                                  c_init, p_init);
 
   return(SIM_RESULTS);
 }
 
-run_farming_sim <- function(IND, LAND, PARAS){
-  .Call("sim_farming", IND, LAND, PARAS);
+run_farming_sim <- function(IND, LAND, PARAS, CROT, PROT, CINIT, PINIT){
+  .Call("sim_farming", IND, LAND, PARAS, CROT, PROT, CINIT, PINIT);
 }
 
 substitute_traits <- function(paras, move_distance, food_needed_surv,
