@@ -31,107 +31,68 @@ double get_pesticide_val(double *paras){
 }
 
 /* =============================================================================
- * Each owner randomly selects a crop to put down
- *     land:        The landscape array to be adjusted
- *     paras:       The paras vector that holds global information
- *     owner_count: Vector of the number
- *     max_own:     The highest ID of a land owner
+ * Initialise pesticides in their starting positions on the landscape
+ *     land:   The landscape array to be adjusted
+ *     paras:  The paras vector that holds global information
+ *     P_init: The matrix for the initial pesticide positions
  * ========================================================================== */
-void rand_pesticide(double ***land, double *paras, int *owner_choice, 
-                    int max_own){
-  
-  int i, j, xdim, ydim, owner, own_layer, choice, layer;
-  int pesticide_number, pesticide_layer_1;
-  
-  xdim              = (int) paras[103];
-  ydim              = (int) paras[104];
-  pesticide_layer_1 = (int) paras[128];
-  pesticide_number  = (int) paras[157];
-  own_layer         = (int) paras[155];
-  
-  for(i = 0; i < max_own; i++){
-      owner_choice[i] = get_rand_int(0, pesticide_number - 1);
-  }
-  
-  for(i = 0; i < xdim; i++){
-      for(j = 0; j < ydim; j++){
-          owner             = (int) land[i][j][own_layer] - 1;
-          choice            = (int) owner_choice[owner];
-          layer             = (int) choice + pesticide_layer_1;  
-          land[i][j][layer] = (double) get_pesticide_val(paras);
-      }
-  }
+void init_pesticide(double ***land, double *paras, double **P_init){
+    
+    int i, j, xdim, ydim, owner, own_layer, choice, layer, farms;
+    int pesticide_number, pesticide_layer_1, *owner_choice;
+    double *init_vec;
+    
+    xdim              = (int) paras[103];
+    ydim              = (int) paras[104];
+    farms             = (int) paras[142];
+    own_layer         = (int) paras[155];
+    pesticide_layer_1 = (int) paras[128];
+    own_layer         = (int) paras[155];
+    pesticide_number  = (int) paras[157];
+    
+    owner_choice = (int *) malloc(farms * sizeof(int));
+    for(i = 0; i < farms; i++){
+        init_vec = (double *) malloc(pesticide_number * sizeof(double));
+        for(j = 0; j < pesticide_number; j++){
+            init_vec[j] = P_init[i][j];
+        }
+        owner_choice[i] = sample_pr_vector(init_vec, pesticide_number);
+        free(init_vec);
+    }
+    
+    for(i = 0; i < xdim; i++){
+        for(j = 0; j < ydim; j++){
+            owner             = (int) land[i][j][own_layer] - 1;
+            choice            = (int) owner_choice[owner];
+            layer             = choice + pesticide_layer_1;
+            land[i][j][layer] = get_pesticide_val(paras);
+        }
+    }
+    
+    free(owner_choice);
 }
 
 /* =============================================================================
- * Does not rotate the pesticide in any way -- just refereshes it
- *     land:        The landscape array to be adjusted
- *     paras:       The paras vector that holds global information
- *     owner_count: Vector of the number
- *     max_own:     The highest ID of a land owner
+ * Change the pesticide choice based on the rotation matrix
+ *     P_init:   The matrix for the initial (current) pesticide positions
+ *     P_change: The matrix describing how pesticide changes occur
+ *     paras:    The paras vector that holds global information
  * ========================================================================== */
-void no_pest_rot(double ***land, double *paras, int *owner_choice, int max_own){
-  
-  int i, j, xdim, ydim, pesticide, owner, own_layer, choice, layer;
-  int pesticide_number, pesticide_layer_1;
-  
-  xdim              = (int) paras[103];
-  ydim              = (int) paras[104];
-  pesticide_layer_1 = (int) paras[128];
-  own_layer         = (int) paras[155];
-  pesticide_number  = (int) paras[157];
-  
-  pesticide = 0;
-  for(i = 0; i < max_own; i++){
-    owner_choice[i] = pesticide;
-    pesticide++;
-    if(pesticide >= pesticide_number){
-      pesticide = 0;
+void change_pesticide_choice(double **P_init, double **P_change, double *paras){
+    
+    int i, j, farms, pesticide_number, now_choice, new_choice;
+    
+    farms             = (int) paras[142];
+    pesticide_number  = (int) paras[157];
+    
+    for(i = 0; i < farms; i++){
+        now_choice = sample_pr_vector(P_init[i], pesticide_number);
+        new_choice = sample_pr_vector(P_change[now_choice], pesticide_number);
+        for(j = 0; j < pesticide_number; j++){
+            P_init[i][j] = 0.0;
+        }
+        P_init[i][new_choice] = 1.0;
     }
-  }
-  
-  for(i = 0; i < xdim; i++){
-    for(j = 0; j < ydim; j++){
-      owner             = (int) land[i][j][own_layer] - 1;
-      choice            = (int) owner_choice[owner];
-      layer             = choice + pesticide_layer_1;
-      land[i][j][layer] = get_pesticide_val(paras);
-    }
-  }
-}
-
-/* =============================================================================
- * Changes the pesticide in a specific way
- *     land:    The landscape array to be adjusted
- *     paras:   The paras vector that holds global information
- *     max_own: The maximum ID of an owner
- * ========================================================================== */
-void change_pesticide(double ***land, double *paras, int max_own){
-  
-  int i;
-  int pesticide_rotate_type, *owner_choice;
-  
-  pesticide_rotate_type = (int) paras[148];
-  
-  owner_choice = (int *) malloc(max_own * sizeof(int));
-  for(i = 0; i < max_own; i++){
-      owner_choice[i] = 0;
-  }
-  
-  switch(pesticide_rotate_type){
-      case 0: /* Nothing happens */
-          break;
-      case 1: /* Heterogeneous pattern but no rotation */
-          no_pest_rot(land, paras, owner_choice, max_own);
-          break;
-      case 2: /* Random selection independent for each owner */
-          rand_pesticide(land, paras, owner_choice, max_own);
-          break;
-      default:
-          break;
-  }
-  
-  free(owner_choice);
 }
 
 /* =============================================================================
@@ -163,111 +124,6 @@ double get_crop_val(double *paras){
     return val;
 }
 
-
-/* =============================================================================
- * Does not rotate the crop in any way -- just refreshes crop on the layer
- *     land:        The landscape array to be adjusted
- *     paras:       The paras vector that holds global information
- *     owner_count: Vector of the number
- *     max_own:     The highest ID of a land owner
- * ========================================================================== */
-void no_crop_rot(double ***land, double *paras, int *owner_choice, int max_own){
-    
-    int i, j, xdim, ydim, crop, owner, own_layer, choice, layer;
-    int crop_number, food_layer_1;
-    
-    xdim         = (int) paras[103];
-    ydim         = (int) paras[104];
-    food_layer_1 = (int) paras[118];
-    own_layer    = (int) paras[155];
-    crop_number  = (int) paras[156];
-    
-    crop = 0;
-    for(i = 0; i < max_own; i++){
-        owner_choice[i] = crop;
-        crop++;
-        if(crop >= crop_number){
-          crop = 0;
-        }
-    }
-    
-    for(i = 0; i < xdim; i++){
-        for(j = 0; j < ydim; j++){
-            owner             = (int) land[i][j][own_layer] - 1;
-            choice            = (int) owner_choice[owner];
-            layer             = choice + food_layer_1;
-            land[i][j][layer] = get_crop_val(paras);
-        }
-    }
-}
-
-/* =============================================================================
- * Each owner randomly selects a crop to put down
- *     land:        The landscape array to be adjusted
- *     paras:       The paras vector that holds global information
- *     owner_count: Vector of the number
- *     max_own:     The highest ID of a land owner
- * ========================================================================== */
-void rand_crop(double ***land, double *paras, int *owner_choice, int max_own){
-  
-    int i, j, xdim, ydim, owner, own_layer, choice, layer;
-    int crop_number, food_layer_1;
-
-    xdim         = (int) paras[103];
-    ydim         = (int) paras[104];
-    food_layer_1 = (int) paras[118];
-    crop_number  = (int) paras[156];
-    own_layer    = (int) paras[155];
-    
-    for(i = 0; i < max_own; i++){
-        owner_choice[i] = get_rand_int(0, crop_number - 1);
-    }
-
-    for(i = 0; i < xdim; i++){
-        for(j = 0; j < ydim; j++){
-            owner             = (int) land[i][j][own_layer] - 1;
-            choice            = owner_choice[owner];
-            layer             = choice + food_layer_1;
-            land[i][j][layer] = get_crop_val(paras);
-        }
-    }
-}
-
-
-/* =============================================================================
- * Changes the crop in a specific way
- *     land:    The landscape array to be adjusted
- *     paras:   The paras vector that holds global information
- *     max_own: The maximum ID of an owner
- * ========================================================================== */
-void change_crop(double ***land, double *paras, int max_own){
-  
-  int i;
-  int crop_rotate_type, *owner_choice;
-  
-  crop_rotate_type = (int) paras[142];
-  
-  owner_choice = (int *) malloc(max_own * sizeof(int));
-  for(i = 0; i < max_own; i++){
-    owner_choice[i] = 0;
-  }
-  
-  switch(crop_rotate_type){
-      case 0: /* Nothing happens */
-          break;
-      case 1: /* Heterogeneous pattern but no rotation */
-          no_crop_rot(land, paras, owner_choice, max_own);
-          break;
-      case 2: /* Random selection independent for each owner */
-          rand_crop(land, paras, owner_choice, max_own);
-          break;
-      default:
-          break;
-  }
-  
-  free(owner_choice);
-}
-
 /* =============================================================================
  * Cleans the landscape of all crops
  *     land:   The landscape array to be adjusted
@@ -308,7 +164,6 @@ void clean_pesticide(double ***land, double *paras){
   }
 }
 
-
 /* =============================================================================
  * Cleans the landscape of all crops
  *     land:   The landscape array to be adjusted
@@ -374,49 +229,99 @@ void clean_landscape(double ***land, double *paras){
   }
 }
 
+ /* =============================================================================
+  * Initialise crops in their starting positions on the landscape
+  *     land:   The landscape array to be adjusted
+  *     paras:  The paras vector that holds global information
+  *     C_init: The matrix for the initial crop positions
+  * ========================================================================== */
+ void init_crop(double ***land, double *paras, double **C_init){
+     
+     int i, j, xdim, ydim, owner, own_layer, choice, layer, farms;
+     int crop_number, food_layer_1, *owner_choice;
+     double *init_vec;
+     
+     xdim         = (int) paras[103];
+     ydim         = (int) paras[104];
+     food_layer_1 = (int) paras[118];
+     farms        = (int) paras[142];
+     own_layer    = (int) paras[155];
+     crop_number  = (int) paras[156];
+     
+     owner_choice = (int *) malloc(farms * sizeof(int));
+     for(i = 0; i < farms; i++){
+         init_vec = (double *) malloc(crop_number * sizeof(double));
+         for(j = 0; j < crop_number; j++){
+             init_vec[j] = C_init[i][j];
+         }
+         owner_choice[i] = sample_pr_vector(init_vec, crop_number);
+         free(init_vec);
+     }
+     
+     for(i = 0; i < xdim; i++){
+         for(j = 0; j < ydim; j++){
+             owner             = (int) land[i][j][own_layer] - 1;
+             choice            = (int) owner_choice[owner];
+             layer             = choice + food_layer_1;
+             land[i][j][layer] = get_crop_val(paras);
+         }
+     }
+     
+     free(owner_choice);
+ }
+
+/* =============================================================================
+ * Change the crop choice based on the rotation matrix
+ *     C_init:   The matrix for the initial (current) crop positions
+ *     C_change: The matrix describing how crop changes occur
+ *     paras:    The paras vector that holds global information
+ * ========================================================================== */
+void change_crop_choice(double **C_init, double **C_change, double *paras){
+    
+    int i, j, farms, crop_number, now_choice, new_choice;
+    
+    farms        = (int) paras[142];
+    crop_number  = (int) paras[156];
+    
+    for(i = 0; i < farms; i++){
+        now_choice = sample_pr_vector(C_init[i], crop_number);
+        new_choice = sample_pr_vector(C_change[now_choice], crop_number);
+        for(j = 0; j < crop_number; j++){
+            C_init[i][j] = 0.0;
+        }
+        C_init[i][new_choice] = 1.0;
+    }
+}
+
 /* =============================================================================
  * Increases the age of each pest by a single time step
- *     land:   The landscape array to be adjusted
- *     paras:  The paras vector that holds global information
- *     ts:     The time step of the simulation
+ *     land:     The landscape array to be adjusted
+ *     paras:    The paras vector that holds global information
+ *     ts:       The time step of the simulation
+ *     C_init:   The matrix for the initial (current) crop positions
+ *     C_change: The matrix describing how crop changes occur
+ *     P_init:   The matrix for the initial (current) pesticide positions
+ *     P_change: The matrix describing how pesticide changes occur
  * ========================================================================== */
-void land_change(double ***land, double *paras, int ts){
+void land_change(double ***land, double *paras, int ts, double **C_init,
+                 double **C_change, double **P_init, double **P_change){
   
-  int i, j, min_own, max_own, own_layer, xdim, ydim, own_val;
   int rotate_crops, rotate_pesticide, start_pesticide;
-  
-  xdim              = (int) paras[103];
-  ydim              = (int) paras[104];
-  own_layer         = (int) paras[155];
+ 
   rotate_crops      = (int) paras[143];
   rotate_pesticide  = (int) paras[149];
   start_pesticide   = (int) paras[168];
-  
-  if(ts % rotate_crops == 0 || ts % rotate_pesticide == 0){
-      min_own = land[0][0][own_layer];
-      max_own = land[0][0][own_layer];
-      for(i = 0; i < xdim; i++){
-          for(j = 0; j < ydim; j++){
-              own_val = (int) land[i][j][own_layer];
-              if(own_val < min_own){
-                  min_own = own_val;
-              }
-              if(own_val > max_own){
-                  max_own = own_val;
-              }
-          }
-      }
-  }
 
   if(ts % rotate_crops == 0){
       clean_crops(land, paras);
-      change_crop(land, paras, max_own);
+      change_crop_choice(C_init, C_change, paras);
+      init_crop(land, paras, C_init);
   }
-  if(ts % rotate_pesticide == 0 && ts > start_pesticide){
+  if(ts % rotate_pesticide == 0 && ts >= start_pesticide){
       clean_pesticide(land, paras);
-      change_pesticide(land, paras, max_own);
+      change_pesticide_choice(P_init, P_change, paras);
+      init_pesticide(land, paras, P_init);
   }
 }
 
 
-
